<?php
/**
 * Vote widget component
 * 
 * @package     Joomla.Administrator
 * @subpackage  com_weightyvote
 * @license GNU General Public License version 3 or later; see LICENSE.txt
 * 
 */

 // No direct access to file
defined('_JEXEC' ) or die;

require_once JPATH_SITE . '/administrator/components/com_weightyvote/defines.php';

jimport('joomla.form.formfield');
 
class JFormFieldVotepreview extends JFormField {
    
    /*
     * Input type
     */
    protected $type = 'votepreview';
    
    /**
     * Sets module param to input class properties
     * 
     * @since 1.0.0
     * @access private
     * @param type $params
     */
    private function setParams($params){
        $this->vote_id = isset($params['vote_id']) ? $params['vote_id'] : "-1";
        $this->borderWg = isset($params['borderWg']) ? $params['borderWg'] : "#333333";
        $this->borderSizeWg = isset($params['borderSizeWg']) ? $params['borderSizeWg'] : "1";
        $this->shadowSize = isset($params['shadowSize']) ? $params['shadowSize'] : "10";
        $this->shadowOpacity = isset($params['shadowOpacity']) ? $params['shadowOpacity'] : "0.5";
        $this->bgHeader = isset($params['bgHeader']) ? $params['bgHeader'] : "#337ab7";
        $this->colorHeader = isset($params['colorHeader']) ? $params['colorHeader'] : "#ffffff";
        $this->borderHeader = isset($params['borderHeader']) ? $params['borderHeader'] : "#337ab7";
        $this->borderSizeHeader = isset($params['borderSizeHeader']) ? $params['borderSizeHeader'] : "1";
        $this->bgBody = isset($params['bgBody']) ? $params['bgBody'] : "#ffffff";
        $this->colorWg = isset($params['colorWg']) ? $params['colorWg'] : "#333333";
        $this->bgAnswerCount = isset($params['bgAnswerCount']) ? $params['bgAnswerCount'] : "#777777";
        $this->colorAnswerCount = isset($params['colorAnswerCount']) ? $params['colorAnswerCount'] : "#ffffff";
        $this->bgButton = isset($params['bgButton']) ? $params['bgButton'] : "#337ab7";
        $this->colorButton = isset($params['colorButton']) ? $params['colorButton'] : "#ffffff";
        $this->borderFooter = isset($params['borderFooter']) ? $params['borderFooter'] : "#c0c0c0";
        $this->borderSizeFooter = isset($params['borderSizeFooter']) ? $params['borderSizeFooter'] : "1";
        $this->bgFooter = isset($params['bgFooter']) ? $params['bgFooter'] : "#f5f5f5";
        $this->colorFooter = isset($params['colorFooter']) ? $params['colorFooter'] : "#333333";
        $this->bgCounter = isset($params['bgCounter']) ? $params['bgCounter'] : "#337ab7";
        $this->colorCounter = isset($params['colorCounter']) ? $params['colorCounter'] : "#ffffff";
        $this->colorLink = isset($params['colorLink']) ? $params['colorLink'] : "#337ab7";
    }
    
    /**
     * Load weightyvote module params
     * 
     * @since 1.0.0
     * @access private
     * @param int $id - weightyvote module id
     * @return array $params - weightyvote module params
     */
    private function load($id)
    {
        $params = [];
        
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $conditions = [
            $db->quoteName('id') . ' = ' . $id, 
        ];

        $query->select($db->quoteName('params'))
                ->from($db->quoteName('#__modules'))
                ->where($conditions);

        $db->setQuery($query);

        $results = $db->loadObjectList();
        foreach($results as $row){
            $params = json_decode($row->params, true);
        }
        
        return $params;
    }
    
    /**
     * Out input to form
     * 
     * @since 1.0.0
     * @access public
     * @return string html element code
     */
    public function getInput() {
        $input = JFactory::getApplication()->input;
        $id = $input->get('id');

        $params = $this->load($id);
        $this->vote_id = isset($params['vote_id']) ? $params['vote_id'] : -1;
        $this->setParams($params);
        $style = json_encode($params);
        $document = JFactory::getDocument();
            
        $document->addScriptDeclaration('var current_vote_id="'.$this->vote_id.'",style='.$style
                . ',params=[],service_domain="'.WEIGHTYVOTE_SERVICE_URL
                . '",widget=null;jQuery(document).ready(function(){getvotes("'.WEIGHTYVOTE_SERVICE_URL
                . '");jQuery(\'#vote-widget-place\').html(\'<div id="vote-widget-'.$this->vote_id.'"><div>\');});');
        $document->addScript(WEIGHTYVOTE_IFVISIBLE_URL);
        $document->addScript(WEIGHTYVOTE_SPECTRUM_URL);
        $document->addScript(WEIGHTYVOTE_JQUERYCOOKIE_URL);
        $document->addScript(WEIGHTYVOTE_SCRIPT_URL);
        $document->addScript(WEIGHTYVOTE_SCRIPT_SETTINGS_URL);
        $document->addScript(WEIGHTYVOTE_CUSTOMIZATIONSCRIPT_URL);
        
        $element = '<div class="span4"><div id="vote-widget-place"></div></div>';
        return $element;
    }
}