<?php
/**
 * WeightyVote widget component
 * 
 * @package     Joomla.Administrator
 * @subpackage  com_weightyvote
 * @license GNU General Public License version 3 or later; see LICENSE.txt
 * 
 */

 // No direct access to file
defined('_JEXEC' ) or die;

jimport('joomla.application.component.model');

class WeightyvoteModelVotes extends JModelLegacy{
    /**
     * Append WeightyVote module in list with default params
     * 
     * @since 1.0.0
     * @access public
     * @return void
     */
    public function appendVote(){
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $params = '{"vote_id":"","borderWg":"#333333","borderSizeWg":"1","shadowSize":"10","shadowOpacity":"0.5","bgHeader":"#337ab7","colorHeader":"#ffffff","borderHeader":"#337ab7","borderSizeHeader":"1","bgBody":"#ffffff","colorWg":"#333333","bgAnswerCount":"#777777","colorAnswerCount":"#ffffff","bgButton":"#337ab7","colorButton":"#ffffff","borderFooter":"#c0c0c0","borderSizeFooter":"1","bgFooter":"#f5f5f5","colorFooter":"#333333","bgCounter":"#337ab7","colorLink":"#337ab7","question":"","answers":"","module_tag":"div","bootstrap_size":"0","header_tag":"h3","header_class":"","style":"0"}';
        $columns = ['title', 'note', 'content', 'ordering', 'position', 'checked_out', 'checked_out_time', 'publish_up', 'publish_down', 'published', 'module', 'access', 'showtitle', 'params', 'client_id', 'language'];
        $values = ['\'WeightyVote\'', '\'\'', '\'\'', 0, '\'\'', 0, '\'0000-00-00 00:00:00\'', '\'0000-00-00 00:00:00\'', '\'0000-00-00 00:00:00\'', 0, '\'mod_weightyvote_widget\'', 1, 0, '\''.$params.'\'', 0, '\'*\''];
        $query
            ->insert($db->quoteName('#__modules'))
            ->columns($db->quoteName($columns))
            ->values(implode(',', $values));
        $db->setQuery($query);
        $db->execute();
    }
    
    /**
     * Remove WeightyVote module by Id
     * 
     * @since 1.0.0
     * @access public
     * @param string $id - weightyvote module id
     * @return bool return true if remove sucessfully
     */
    public function removeVote($id){
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $conditions = array(
             $db->quoteName('id') . ' = ' . $id, 
        );

        $query->delete($db->quoteName('#__modules'));
        $query->where($conditions);

        $db->setQuery($query);

        $result = $db->execute();
        
        return $result;
    }
    
    /**
     * Publish weightyvote module
     * 
     * @since 1.0.0
     * @access public
     * @param string $id - weightyvote module id
     * @param bool $publish - set false to unpublish vote, true-default
     * @return bool return true if success
     */
    public function publishVote($id, $publish=true){
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $fields = [
            $db->quoteName('published') . ' = ' . ($publish ? '1' : '0')
        ];
        $conditions = [
            $db->quoteName('id') . ' = ' . $id, 
        ];

        $query->update($db->quoteName('#__modules'))->set($fields)->where($conditions);

        $db->setQuery($query);

        $result = $db->execute();
        
        return $result;
    }
    
    /**
     * Get weightyvote module list
     * 
     * @since 1.0.0
     * @access public
     * @return array [..['name', 'id', 'published', 'vote']..] where
     *          name - weightyvote module title, 
     *          id - module id,
     *          publised - true if module published,
     *          vote - vote_id from module params
     */
    public function getVotes(){
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select($db->quoteName(['id', 'title', 'published', 'params']));
        $query->from($db->quoteName('#__modules'));
        $query->where($db->quoteName('module') . ' = \'mod_weightyvote_widget\'');
        $query->order('ordering ASC');
        $db->setQuery($query);
 
        $results = $db->loadObjectList();

        $items = [];
        foreach($results as $row){
            $item = [];
            $item['name'] = $row->title;
            $item['id'] = $row->id;
            $item['published'] = $row->published;
            $item['vote'] = isset(json_decode($row->params)->vote_id) ? json_decode($row->params)->vote_id : '';
            
            $items[] = $item;
        }
        
        return $items;
    }
}