<?php
/**
 * WeightyVote widget component
 * 
 * @package     Joomla.Administrator
 * @subpackage  com_weightyvote
 * @license GNU General Public License version 3 or later; see LICENSE.txt
 * 
 */

 // No direct access to file
defined('_JEXEC' ) or die;
 
/**
 * HTML View class for the Vote Widget Component
 *
 * @since  1.0.0
 */
class WeightyvoteViewSettings extends JViewLegacy
{
    /**
     * Append JQuery script in noConfict mode
     *
     * @param void
     * @access private
     */
    private static function addJQuery(){
        $document = JFactory::getDocument();
        
        if (version_compare(JVERSION, '3.0', 'lt'))
        {
            // Joomla version lower 3.0
            JHTML::_('behavior.framework');
            // load jQuery, if not loaded before
            if (!JFactory::getApplication()->get('jquery'))
            {
                JFactory::getApplication()->set('jquery', true);
                // add jQuery
                $document->addScript('https://ajax.googleapis.com/ajax/libs/jquery/1.8.3/jquery.min.js');
                $document->addScriptDeclaration('jQuery.noConflict();');
            }
        } else {
            /* use JQuery framework in noConflict mode */
            JHtml::_('jquery.framework');
        }
    }
    
    /**
     * Return module params
     * 
     * @since 1.0.0
     * @access  public
     * @return  array associative array of params
     */
    private function getParams(){
        $model = $this->getModel();

        $params = $model->load($this->id);
        $this->vote_id = isset($params['vote_id']) ? $params['vote_id'] : "-1";
        $this->borderWg = isset($params['borderWg']) ? $params['borderWg'] : "#333333";
        $this->borderSizeWg = isset($params['borderSizeWg']) ? $params['borderSizeWg'] : "1";
        $this->shadowSize = isset($params['shadowSize']) ? $params['shadowSize'] : "10";
        $this->shadowOpacity = isset($params['shadowOpacity']) ? $params['shadowOpacity'] : "0.5";
        $this->bgHeader = isset($params['bgHeader']) ? $params['bgHeader'] : "#337ab7";
        $this->colorHeader = isset($params['colorHeader']) ? $params['colorHeader'] : "#ffffff";
        $this->borderHeader = isset($params['borderHeader']) ? $params['borderHeader'] : "#337ab7";
        $this->borderSizeHeader = isset($params['borderSizeHeader']) ? $params['borderSizeHeader'] : "1";
        $this->bgBody = isset($params['bgBody']) ? $params['bgBody'] : "#ffffff";
        $this->colorWg = isset($params['colorWg']) ? $params['colorWg'] : "#333333";
        $this->bgAnswerCount = isset($params['bgAnswerCount']) ? $params['bgAnswerCount'] : "#777777";
        $this->colorAnswerCount = isset($params['colorAnswerCount']) ? $params['colorAnswerCount'] : "#ffffff";
        $this->bgButton = isset($params['bgButton']) ? $params['bgButton'] : "#337ab7";
        $this->colorButton = isset($params['colorButton']) ? $params['colorButton'] : "#ffffff";
        $this->borderFooter = isset($params['borderFooter']) ? $params['borderFooter'] : "#c0c0c0";
        $this->borderSizeFooter = isset($params['borderSizeFooter']) ? $params['borderSizeFooter'] : "1";
        $this->bgFooter = isset($params['bgFooter']) ? $params['bgFooter'] : "#f5f5f5";
        $this->colorFooter = isset($params['colorFooter']) ? $params['colorFooter'] : "#333333";
        $this->bgCounter = isset($params['bgCounter']) ? $params['bgCounter'] : "#337ab7";
        $this->colorCounter = isset($params['colorCounter']) ? $params['colorCounter'] : "#ffffff";
        $this->colorLink = isset($params['colorLink']) ? $params['colorLink'] : "#337ab7";

        return $params;
    }

    /**
     * Display the Settings view
     *
     * @since 1.0.0
     * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
     * @access  public
     * @return  void
     */
    function display($tpl = null)
    {
        self::addJQuery();

        $input = JFactory::getApplication()->input;
        $this->id = $input->get('id');
        $this->title = JText::_('COM_WEIGHTYVOTE_WIDGET_SETTINGS_TITLE');
        
        $style = json_encode($this->getParams());

        $this->addToolbar();

        $document = JFactory::getDocument();
        $document->addScriptDeclaration('var current_vote_id="'.$this->vote_id.'",widget_style='.$style.',params=[],service_domain="'.WEIGHTYVOTE_SERVICE_URL.'",widget=null;jQuery(document).ready(function(){getvotes("'.WEIGHTYVOTE_SERVICE_URL.'");});');
        $document->addStyleSheet(WEIGHTYVOTE_STYLE_SPECTRUM_URL);
        $document->addScript(WEIGHTYVOTE_IFVISIBLE_URL);
        $document->addScript(WEIGHTYVOTE_SPECTRUM_URL);
        $document->addScript(WEIGHTYVOTE_JQUERYCOOKIE_URL);
        $document->addScript(WEIGHTYVOTE_SCRIPT_URL);
        $document->addScript(WEIGHTYVOTE_SCRIPT_SETTINGS_URL);
        $document->addScript(WEIGHTYVOTE_CUSTOMIZATIONSCRIPT_URL);

        // Display the view
        parent::display($tpl);
    }

    /**
     * Create toolbar with buttons
     * 
     * @since 1.0.0
     * @access protected
     * @return void
     */
    protected function addToolbar()
    {
        JToolBarHelper::title(JText::_('COM_WEIGHTYVOTE_WIDGET_TOOLBAR_TITLE'));
        JToolBarHelper::back('JTOOLBAR_BACK', 'index.php?option='.JRequest::getCmd('option',''));
        JToolBarHelper::apply('settings.apply', 'JTOOLBAR_APPLY');
        JToolBarHelper::editList('settings.edit', 'JTOOLBAR_EDIT');
    }
}