<?php
/**
 * WeightyVote widget component
 * 
 * @package     Joomla.Administrator
 * @subpackage  com_weightyvote
 * @license GNU General Public License version 3 or later; see LICENSE.txt
 * 
 */

 // No direct access to file
defined('_JEXEC' ) or die;

jimport( 'joomla.application.component.view');

/**
 * HTML View class for the Vote Widget Component
 *
 */
class WeightyvoteViewVotes extends JViewLegacy
{   
    /**
     * Append JQuery script in noConfict mode
     *
     * @param void
     * @access private
     */
    private static function addJQuery(){
        $document = JFactory::getDocument();
        
        if (version_compare(JVERSION, '3.0', 'lt'))
        {
            // Joomla version lower 3.0
            JHTML::_('behavior.framework');
            // load jQuery, if not loaded before
            if (!JFactory::getApplication()->get('jquery'))
            {
                JFactory::getApplication()->set('jquery', true);
                // add jQuery
                $document->addScript('https://ajax.googleapis.com/ajax/libs/jquery/1.8.3/jquery.min.js');
                $document->addScriptDeclaration('jQuery.noConflict();');
            }
        } else {
            /* use JQuery framework in noConflict mode */
            JHtml::_('jquery.framework');
        }
    }
    
    /**
     * Display the Votes view
     *
     * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
     * @access public
     * @return  void
     */
    function display($tpl = null)
    {
        self::addJQuery();
        $this->addToolbar();
        
        $document = JFactory::getDocument();
        $document->addScript(WEIGHTYVOTE_SCRIPT_VOTES_URL);
        $document->addScriptDeclaration('var service_domain = "'. WEIGHTYVOTE_SERVICE_URL
                . '";jQuery(window).on(\'load\', function(){getvotes(service_domain);});');
        
        $this->title = JText::_('COM_WEIGHTYVOTE_VOTES_TITLE');
        $model = $this->getModel();
        $votes = [];
        if ($model){
            $votes = $model->getVotes();
        }
        $this->tableTitle = JText::_('COM_WEIGHTYVOTE_WIDGET_VOTES_TABLE_TITLE');
        $this->table = '';
        
        if (count($votes)){
            $this->table .= '<table class="table table-condensed table-hover"><thead>';
            $this->table .= '<th>Title</th><th>Category / Question</th><th>Status</th><th>Customize</th><th>Edit</th><th>Remove</th>';
            $this->table .= '</thead><tbody>';
            foreach ($votes as $v){
                $this->table .= '<tr><td>' . $v['name'] . '</td><td><a href="'
                    . JRoute::_('index.php?option=com_weightyvote&view=edit&id='.$v['id'], false)
                    . '" class="voteid'.$v['vote'].'">Set category</a></td><td><a href="'
                    . JRoute::_('index.php?option=com_weightyvote&task='
                    . ($v['published'] ? 'votes.unpub' : 'votes.publish').'&id='.$v['id'], false)
                    . '"><span class="'
                    . ($v['published'] ? 'icon-publish' : 'icon-unpublish') 
                    . '" aria-hidden="true"> </span></a></td><td><a href="'
                    . JRoute::_('index.php?option=com_weightyvote&view=settings&id='.$v['id'], false)
                    . '"><span class="icon-options" aria-hidden="true" align="center"> </span></a></td><td><a href="'
                    . JRoute::_('index.php?option=com_modules&task=module.edit&id='.$v['id'], false)
                    . '"><span class="icon-edit" aria-hidden="true"> </span></a></td><td><a href="'
                    . JRoute::_('index.php?option=com_weightyvote&task=votes.remove&id='.$v['id'], false)
                    . '"><span class="icon-delete" aria-hidden="true"> </span></a></td></tr>';
            }
            $this->table .= '</tbody></table>';
        } else {
            $this->table .= JText::_('COM_WEIGHTYVOTE_WIDGET_VOTESNOTEXISTS');
        }
        
        // Display the view
        parent::display($tpl);
    }
    
    /**
     * Add component toolbar with buttons
     * 
     * @access protected
     * @return void
     */
    protected function addToolbar()
    {
        JToolBarHelper::title(JText::_('COM_WEIGHTYVOTE_WIDGET_TOOLBAR_TITLE'));
        JToolBarHelper::addNew('votes.append', 'Append');
    }
}